# pylint: disable=protected-access
import logging

from dvclive.utils import parse_metrics

logger = logging.getLogger(__name__)


def _get_unsent_datapoints(plot, latest_step):
    return [x for x in plot if int(x["step"]) > latest_step]


def _cast_to_numbers(datapoints):
    for datapoint in datapoints:
        for k, v in datapoint.items():
            if k == "step":
                datapoint[k] = int(v)
            elif k == "timestamp":
                continue
            else:
                datapoint[k] = float(v)
    return datapoints


def _to_dvc_format(plots):
    formatted = {}
    for k, v in plots.items():
        formatted[k] = {"data": v}
    return formatted


def get_studio_updates(live):
    plots, metrics = parse_metrics(live)
    latest_step = live._latest_studio_step

    for name, plot in plots.items():
        datapoints = _get_unsent_datapoints(plot, latest_step)
        plots[name] = _cast_to_numbers(datapoints)

    metrics = {live.metrics_file: {"data": metrics}}
    plots = _to_dvc_format(plots)
    return metrics, plots
